Package: SomaticCancerAlterations
Type: Package
Title: Somatic Cancer Alterations
Version: 1.48.0
Author: Julian Gehring
Maintainer: Julian Gehring <jg-bioc@gmx.com>
Imports: GenomicRanges, IRanges, S4Vectors
Depends: R (>= 3.5.0)
Suggests: testthat, ggbio, ggplot2, knitr
VignetteBuilder: knitr
Description: Collection of somatic cancer alteration datasets
License: GPL-3
LazyLoad: yes
biocViews: ExperimentData, Genome, CancerData, Project1000genomes, NCI
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/SomaticCancerAlterations
git_branch: RELEASE_3_23
git_last_commit: b0c3bfb
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 15:44:02 UTC; biocbuild
